Command Line Interface tools
============================

*idc-index* provides a command line interface (CLI) tool to simplify access to the functionality
implemented via the Python API. The CLI tool is a wrapper around the Python API and provides a
simple way to interact with the package.

Once *idc-index* is installed, the CLI tool can be accessed by running the following command in the
terminal.

.. click:: idc_index.cli:idc
  :prog: idc
  :nested: full
